@@ -30,8 +30,12 @@ impl PlotNum for f64 {
         write_interval_float(formatter, *self, step)
     }
 
-    fn unit_range() -> [Self; 2] {
-        [-1.0, 1.0]
+    fn unit_range(offset: Option<Self>) -> [Self; 2] {
+        if let Some(o) = offset {
+            [o - 1.0, o + 1.0]
+        } else {
+            [-1.0, 1.0]
+        }
     }
 
     fn scale(&self, val: [Self; 2], max: f64) -> f64 {
@@ -77,15 +81,6 @@ pub fn compute_ticks_f64(
         ticks.push(Tick { position, value });
     }
 
-    /*
-    //TODO needed to aovid 10 dashes between ticks.
-    //see hover shader example.
-    let dash_multiple = if good_normalized_step == 10 {
-        5
-    } else {
-        good_normalized_step
-    };
-    */
     let dash_multiple = good_normalized_step;
 
     TickInfo {
@@ -103,29 +98,25 @@ pub fn compute_ticks_i128(
     good_ticks: &[u32],
     range: [i128; 2],
 ) -> TickInfo<i128> {
-    //let ideal_num_steps=(ideal_num_steps as i128).min(  (range[1]-range[0]).abs() +1 ) as u32;
-
     let (step, good_normalized_step) = find_good_step_int(good_ticks, ideal_num_steps, range);
     let (start_step, step_num) = get_range_info_int(step, range);
 
+    let display_relative = determine_if_should_use_strat(
+        start_step as f64,
+        (start_step + ((step_num - 1) as i128) * step) as f64,
+        step as f64,
+    );
+
+    let first_tick = if display_relative { 0 } else { start_step };
+
     let mut ticks = Vec::with_capacity(usize::try_from(step_num).unwrap());
     for a in 0..step_num {
         let position = start_step + step * (a as i128);
-        ticks.push(Tick {
-            position,
-            value: position,
-        });
+        let value = first_tick + step * (a as i128);
+
+        ticks.push(Tick { position, value });
     }
 
-    /*
-    //TODO needed to aovid 10 dashes between ticks.
-    //see hover shader example.
-    let dash_multiple = if good_normalized_step == 10 {
-        5
-    } else {
-        good_normalized_step
-    };
-    */
     let dash_multiple = good_normalized_step;
 
     TickInfo {
@@ -133,7 +124,7 @@ pub fn compute_ticks_i128(
         step,
         start_step,
         dash_multiple,
-        display_relative: None,
+        display_relative: display_relative.then(|| start_step),
     }
 }
 
@@ -191,7 +182,7 @@ pub fn compute_dash_size<I: PlotNum>(
 /// Ticks will apear at 1,2,6,12 instead of 1,2,5,10.
 /// See the month example.
 ///
-#[derive(Copy, Clone, PartialEq, PartialOrd)]
+#[derive(Debug, Copy, Clone, PartialEq, PartialOrd)]
 pub struct MonthIndex(pub i128);
 
 impl fmt::Display for MonthIndex {
@@ -236,8 +227,12 @@ impl PlotNum for MonthIndex {
         }
     }
 
-    fn unit_range() -> [Self; 2] {
-        [MonthIndex(-1), MonthIndex(1)]
+    fn unit_range(offset: Option<Self>) -> [Self; 2] {
+        if let Some(o) = offset {
+            [MonthIndex(o.0 - 1), MonthIndex(o.0 + 1)]
+        } else {
+            [MonthIndex(-1), MonthIndex(1)]
+        }
     }
 
     fn fmt_tick(
@@ -289,8 +284,12 @@ impl PlotNum for i128 {
         compute_ticks_i128(ideal_num_steps, &[1, 2, 5, 10], range)
     }
 
-    fn unit_range() -> [Self; 2] {
-        [-1, 1]
+    fn unit_range(offset: Option<Self>) -> [Self; 2] {
+        if let Some(o) = offset {
+            [o - 1, o + 1]
+        } else {
+            [-1, 1]
+        }
     }
 
     fn fmt_tick(
@@ -548,32 +547,40 @@ pub(crate) fn find_bounds2<X: PlotNum, Y: PlotNum>(
         ii.fold(&mut val, |val, (x, y)| {
             if x < val.0[0] {
                 val.0[0] = x;
-                xmoved = true;
+                if !xmoved {
+                    xmoved = true
+                };
             } else if x > val.0[1] {
                 val.0[1] = x;
-                xmoved = true;
+                if !xmoved {
+                    xmoved = true
+                };
             }
             if y < val.1[0] {
                 val.1[0] = y;
-                ymoved = true;
+                if !ymoved {
+                    ymoved = true
+                };
             } else if y > val.1[1] {
                 val.1[1] = y;
-                ymoved = true;
+                if !ymoved {
+                    ymoved = true
+                };
             }
             val
         });
 
         if !xmoved {
-            val.0 = X::unit_range();
+            val.0 = X::unit_range(Some(x));
         }
 
         if !ymoved {
-            val.1 = Y::unit_range();
+            val.1 = Y::unit_range(Some(y));
         }
 
         val
     } else {
-        (X::unit_range(), Y::unit_range())
+        (X::unit_range(None), Y::unit_range(None))
     }
 }
 
@@ -612,7 +619,7 @@ pub fn no_dash_tuple<A: crate::Plottable<X, Y>, X: PlotNum, Y: PlotNum>(
 pub struct NoDash<I: PlotNum>(pub I);
 impl<I: PlotNum> fmt::Display for NoDash<I> {
     fn fmt(&self, a: &mut fmt::Formatter) -> fmt::Result {
-        self.0.fmt(a)
+        std::fmt::Display::fmt(&self.0, a)
     }
 }
 
@@ -629,8 +636,8 @@ impl<I: PlotNum> PlotNum for NoDash<I> {
         I::compute_ticks(ideal_num_steps, [range[0].0, range[1].0]).map(NoDash)
     }
 
-    fn unit_range() -> [Self; 2] {
-        let [a, b] = I::unit_range();
+    fn unit_range(o: Option<Self>) -> [Self; 2] {
+        let [a, b] = I::unit_range(o.map(|x| x.0));
         [NoDash(a), NoDash(b)]
     }
 
